@@ -1,5 +1,6 @@
 """ Excel uploader module
 """
+
 import logging
 
 from xlrd import open_workbook
@@ -162,7 +163,7 @@ class ExcelUploaderModule(AbstractPopupModule):
         if table_name is None:
             return False
 
-        if type(table) != dict:
+        if not isinstance(table, dict):
             return False
 
         table_keys_set = set(table.keys())
